pygor3 package
==============


Submodules
----------

pygor3.AIRR module
------------------

.. automodule:: pygor3.AIRR
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorBestScenarios module
-------------------------------

.. automodule:: pygor3.IgorBestScenarios
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorDefaults module
--------------------------

.. automodule:: pygor3.IgorDefaults
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorDictionaries module
------------------------------

.. automodule:: pygor3.IgorDictionaries
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorIO module
--------------------

.. automodule:: pygor3.IgorIO
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorIndexedSequence module
---------------------------------

.. automodule:: pygor3.IgorIndexedSequence
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorIndexedSequencesDB module
------------------------------------

.. automodule:: pygor3.IgorIndexedSequencesDB
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorSQL module
---------------------

.. automodule:: pygor3.IgorSQL
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorSqliteDB module
--------------------------

.. automodule:: pygor3.IgorSqliteDB
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.IgorSqliteDBBestScenarios module
---------------------------------------

.. automodule:: pygor3.IgorSqliteDBBestScenarios
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.config module
--------------------

.. automodule:: pygor3.config
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.imgt module
------------------

.. automodule:: pygor3.imgt
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.utils module
-------------------

.. automodule:: pygor3.utils
   :members:
   :undoc-members:
   :show-inheritance:

pygor3.utils\_pre\_processing module
------------------------------------

.. automodule:: pygor3.utils_pre_processing
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pygor3
   :members:
   :undoc-members:
   :show-inheritance:


Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygor3.scripts
